@@ -6,11 +6,13 @@ mask2Te <- function(mask){
 	Te_ptr_list <- vector(mode = "list", length = ne)
 	Te_scn <- vector(mode = "numeric", length = ne + 1)
 	Te_ptr_scn <- vector(mode = "numeric", length = ne + 1)
+	w <- vector(mode = "numeric", length = ne)
 	Te_scn[1] <- 1
 	Te_ptr_scn[1] <- 1
 	for(i in 1:ne){
 		mask_lgCMatrix <- drop0(as(mask == ge[i], "sparseMatrix"))
 		Te_list[[i]] <- mask_lgCMatrix@i + 1
+		w[i] <- length(mask_lgCMatrix@i) / 2
 		Te_scn[i + 1] <- Te_scn[i] + length(Te_list[[i]])
 		Te_ptr_list[[i]] <- mask_lgCMatrix@p + 1
 		Te_ptr_scn[i + 1] <- Te_ptr_scn[i] + length(Te_ptr_list[[i]])
@@ -19,6 +21,6 @@ mask2Te <- function(mask){
 	Te_ptr <- unlist(Te_ptr_list)
 	if(is.character(ge)) nme <- ge
 	else nme <- as.character(ge)
-	out <- list(Te = Te, Te_scn = Te_scn, Te_ptr = Te_ptr, Te_ptr_scn = Te_ptr_scn, ne = ne, nme = nme)
+	out <- list(Te = Te, Te_scn = Te_scn, Te_ptr = Te_ptr, Te_ptr_scn = Te_ptr_scn, ne = ne, w = w, nme = nme)
 	out
 }
